* Create Agriculture Census

set more off
clear all

set maxvar 30000
tempfile t30 t25 t20 t10 t00 t90

*** Get farm value:


********************************************************************************
*	Farm Value over time
********************************************************************************
use "Create_AgriculturalCensus\Input\ICPSR_35206\DS0001\35206-0001-Data.dta", clear

tab NAME if LEVEL==2

gen help = STATE if LEVEL==2
bysort STATE: egen US_State = max(help)
drop help

duplicates drop FIPS, force
reshape long FAVAL, i(FIPS) j(Year)
rename FAVAL FarmValueAcre

label variable FarmValueAcre "Average Value Farm per Acre"

replace Year=Year+1000

save "Create_AgriculturalCensus\temp\temp.dta", replace


keep if Year==1940
gen n = 1
expand 10
bysort FIPS: replace n = sum(n)
replace Year=1964 if n==1
replace Year=1969 if n==2
replace Year=1974 if n==3
replace Year=1978 if n==4
replace Year=1982 if n==5
replace Year=1987 if n==6
replace Year=1992 if n==7
replace Year=1997 if n==8
replace Year=2002 if n==9
replace Year=2007 if n==10
replace FarmValue=. if n!=.

append using "Create_AgriculturalCensus\temp\temp.dta"

save "Create_AgriculturalCensus\temp\temp.dta", replace


use "Create_AgriculturalCensus\temp\temp.dta", clear

keep if Year==1890
rename FIPS FIPS90
replace FIPS90 = 16350 if STATE==63&COUNTY==35
replace FIPS90 = 16635 if STATE==63&COUNTY==635
qui tab FIPS90 if FarmValueAcre!=.&FarmValueAcre!=0
di `r(r)'


save "Create_AgriculturalCensus\temp\test.dta", replace



**** Transform 1890s boundaries to 1935 (i.e. the treatment year)**************
use "Create_AgriculturalCensus\Input\T9035.dta", clear
qui tab FIPS90
di `r(r)'
qui tab FIPS35
di `r(r)'
keep if FIPS35!=0&FIPS90!=0

gen Share = F_AREA/AREA90
sort FIPS90
merge m:1 FIPS90 using "Create_AgriculturalCensus\temp\test.dta"

foreach var of varlist FarmValueAcre  {

replace `var' = `var'*Share
}

collapse (sum) FarmValueAcre , by(FIPS35 Year)

rename FIPS35 FIPS
qui tab FIPS
di `r(r)'

rename FarmValueAcre FarmValueAcre_adj

save `t90', replace 



******* Transform 1900s boundaries to 1935 (i.e. the treatment year)************
use "Create_AgriculturalCensus\temp\temp.dta", clear

keep if Year==1900
rename FIPS FIPS00
qui tab FIPS00 if FarmValueAcre!=.&FarmValueAcre!=0
di `r(r)'

save "Create_AgriculturalCensus\temp\test.dta", replace


use "Create_AgriculturalCensus\Input\T0035.dta", clear

qui tab FIPS00
di `r(r)'
qui tab FIPS35
di `r(r)'
keep if FIPS35!=0&FIPS00!=0

gen Share = F_AREA/AREA00
sort FIPS00

merge m:1 FIPS00 using "Create_AgriculturalCensus\temp\test.dta"

foreach var of varlist FarmValueAcre  {

replace `var' = `var'*Share
}

collapse (sum) FarmValueAcre , by(FIPS35 Year)
rename FIPS35 FIPS
qui tab FIPS
di `r(r)'

rename FarmValueAcre FarmValueAcre_adj
save `t00', replace 



***** Transform 1910s boundaries to 1935 (i.e. the treatment year)**************
use "Create_AgriculturalCensus\temp\temp.dta", clear


keep if Year==1910
rename FIPS FIPS10
qui tab FIPS10 if FarmValueAcre!=.&FarmValueAcre!=0
di `r(r)'

save "Create_AgriculturalCensus\temp\test.dta", replace


use "Create_AgriculturalCensus\Input\T1035.dta", clear
qui tab FIPS10
di `r(r)'
qui tab FIPS35
di `r(r)'
keep if FIPS35!=0&FIPS10!=0

gen Share = F_AREA/AREA10
sort FIPS10

merge m:1 FIPS10 using "Create_AgriculturalCensus\temp\test.dta"

foreach var of varlist FarmValueAcre  {

replace `var' = `var'*Share
}

collapse (sum) FarmValueAcre , by(FIPS35 Year)
rename FIPS35 FIPS
qui tab FIPS
di `r(r)'
rename FarmValueAcre FarmValueAcre_adj

save `t10', replace 
qui tab FIPS if FarmValueAcre!=.&FarmValueAcre!=0
di `r(r)'



********* Transform 1920s boundaries to 1935 (i.e. the treatment year)**********
use "Create_AgriculturalCensus\temp\temp.dta", clear

keep if Year==1920
rename FIPS FIPS20
qui tab FIPS20 if FarmValueAcre!=.&FarmValueAcre!=0
di `r(r)'

save "Create_AgriculturalCensus\temp\test.dta", replace


use "Create_AgriculturalCensus\Input\T2035.dta", clear
qui tab FIPS20
di `r(r)'
qui tab FIPS35
di `r(r)'
keep if FIPS35!=0&FIPS20!=0

gen Share = F_AREA/AREA20
sort FIPS20

merge m:1 FIPS20 using "Create_AgriculturalCensus\temp\test.dta"

foreach var of varlist FarmValueAcre  {

replace `var' = `var'*Share
}

collapse (sum) FarmValueAcre , by(FIPS35 Year)

rename FIPS35 FIPS
qui tab FIPS
di `r(r)'

rename FarmValueAcre FarmValueAcre_adj

save `t20', replace 



******** Transform 1925s boundaries to 1935 (i.e. the treatment year)***********
use "Create_AgriculturalCensus\temp\temp.dta", clear

keep if Year==1925
rename FIPS FIPS25

qui tab FIPS25 if FarmValueAcre!=.&FarmValueAcre!=0
di `r(r)'

save "Create_AgriculturalCensus\temp\test.dta", replace



use "Create_AgriculturalCensus\Input\T2535.dta", clear
qui tab FIPS25
di `r(r)'
qui tab FIPS35
di `r(r)'
keep if FIPS35!=0&FIPS25!=0

gen Share = F_AREA/AREA25
sort FIPS25

merge m:1 FIPS25 using "Create_AgriculturalCensus\temp\test.dta"

foreach var of varlist FarmValueAcre  {

replace `var' = `var'*Share
}

collapse (sum) FarmValueAcre , by(FIPS35 Year)

rename FIPS35 FIPS
qui tab FIPS
di `r(r)'

rename FarmValueAcre FarmValueAcre_adj

save `t25', replace 



******** Transform 1930s boundaries to 1935 (i.e. the treatment year)***********
use "Create_AgriculturalCensus\temp\temp.dta", clear

keep if Year==1930
rename FIPS FIPS30
qui tab FIPS30 if FarmValueAcre!=.&FarmValueAcre!=0
di `r(r)'

save "Create_AgriculturalCensus\temp\test.dta", replace



use "Create_AgriculturalCensus\Input\T3035.dta", clear
qui tab FIPS30
di `r(r)'
qui tab FIPS35
di `r(r)'
keep if FIPS35!=0&FIPS30!=0

gen Share = F_AREA/AREA30
sort FIPS30

merge m:1 FIPS30 using "Create_AgriculturalCensus\temp\test.dta"

foreach var of varlist FarmValueAcre  {

replace `var' = `var'*Share
}

collapse (sum) FarmValueAcre , by(FIPS35 Year)

rename FIPS35 FIPS
qui tab FIPS
di `r(r)'

rename FarmValueAcre FarmValueAcre_adj


save `t30', replace 



******* Merge:
use "Create_AgriculturalCensus\temp\temp.dta", clear


merge 1:1 FIPS Year using `t90'

qui tab FIPS if FarmValueAcre!=.&FarmValueAcre!=0&Year==1890
di `r(r)'
qui tab FIPS if FarmValueAcre_adj!=.&FarmValueAcre_adj!=0&Year==1890
di `r(r)'

replace FarmValueAcre = FarmValueAcre_adj if Year==1890

keep if _merge!=2
drop _merge FarmValueAcre_adj

merge 1:1 FIPS Year using `t00'

qui tab FIPS if FarmValueAcre!=.&FarmValueAcre!=0&Year==1900
di `r(r)'
qui tab FIPS if FarmValueAcre_adj!=.&FarmValueAcre_adj!=0&Year==1900
di `r(r)'

replace FarmValueAcre = FarmValueAcre_adj if Year==1900

keep if _merge!=2
drop _merge FarmValueAcre_adj

merge 1:1 FIPS Year using `t10'

qui tab FIPS if FarmValueAcre!=.&FarmValueAcre!=0&Year==1910
di `r(r)'
qui tab FIPS if FarmValueAcre_adj!=.&FarmValueAcre_adj!=0&Year==1910
di `r(r)'

replace FarmValueAcre = FarmValueAcre_adj if Year==1910

keep if _merge!=2
drop _merge FarmValueAcre_adj

merge 1:1 FIPS Year using `t20'

qui tab FIPS if FarmValueAcre!=.&FarmValueAcre!=0&Year==1920
di `r(r)'
qui tab FIPS if FarmValueAcre_adj!=.&FarmValueAcre_adj!=0&Year==1920
di `r(r)'

replace FarmValueAcre = FarmValueAcre_adj if Year==1920

keep if _merge!=2
drop _merge FarmValueAcre_adj

merge 1:1 FIPS Year using `t25'

qui tab FIPS if FarmValueAcre!=.&FarmValueAcre!=0&Year==1925
di `r(r)'
qui tab FIPS if FarmValueAcre_adj!=.&FarmValueAcre_adj!=0&Year==1925
di `r(r)'

replace FarmValueAcre = FarmValueAcre_adj if Year==1925

keep if _merge!=2
drop _merge FarmValueAcre_adj

merge 1:1 FIPS Year using `t30'

qui tab FIPS if FarmValueAcre!=.&FarmValueAcre!=0&Year==1930
di `r(r)'
qui tab FIPS if FarmValueAcre_adj!=.&FarmValueAcre_adj!=0&Year==1930
di `r(r)'

replace FarmValueAcre = FarmValueAcre_adj if Year==1930

keep if _merge!=2
drop _merge FarmValueAcre_adj

save "Create_AgriculturalCensus\temp\temp.dta", replace


********************************************************************************
********************************************************************************
*** Take Variables from Census
********************************************************************************
********************************************************************************

********************************************************************************
*	1890
********************************************************************************

use "Create_AgriculturalCensus\Input\ICPSR_35206\DS0007\35206-0007-Data.dta", clear
gen Year = 1890 

rename TOTPOP TotPop
gen Cattle = COWS+OXEN+OTCATTLE

rename FARMVAL Value_Land 
rename LIVSTOCK ValueLifeStock
gen Value_Farm = Value_Land+EQUIPVAL

rename FARMS Farms
rename FARMSIZE FarmSize
rename FARMOWN FarmOwn


gen FarmSize_09 = FARM09 
gen FarmSize_1019 = FARM1019 
gen FarmSize_2049 = FARM2049 
gen FarmSize_5099 = FARM5099 
gen FarmSize_100 = FARM100 
gen FarmSize_500 = FARM500  
gen FarmSize_1000 =FARM1000

local list TotPop Cattle Value_Land ValueLifeStock Value_Farm Farms FarmSize FarmOwn ///
	FarmSize_09 FarmSize_1019 FarmSize_2049 FarmSize_5099 FarmSize_100 FarmSize_500 FarmSize_1000 

#delimit ;
keep `list'
	Year FIPS LEVEL STATE COUNTY NAME ;
	
#delimit cr

*** Redraw to 1935 boundaries:

format FIPS %5.0f
keep if FIPS!=.
duplicates drop FIPS, force

gen FIPS90 = FIPS
replace FIPS90 = 16350 if STATE==63&COUNTY==35
replace FIPS90 = 16635 if STATE==63&COUNTY==635

save "Create_AgriculturalCensus\temp\test.dta", replace 


use "Create_AgriculturalCensus\Input\T9035.dta", clear
qui tab FIPS90
di `r(r)'
qui tab FIPS35
di `r(r)'
keep if FIPS35!=0&FIPS90!=0

gen Share = F_AREA/AREA90
sort FIPS90

merge m:1 FIPS90 using "Create_AgriculturalCensus\temp\test.dta",

foreach var of local list {
	replace `var' = `var'*Share
}

collapse (sum) `list' , by(FIPS35 Year)

rename FIPS35 FIPS

merge 1:1 FIPS Year using "Create_AgriculturalCensus\temp\temp.dta"

rename _merge merge_1890

save "Create_AgriculturalCensus\temp\temp.dta", replace



********************************************************************************
*	1900
********************************************************************************
use "Create_AgriculturalCensus\Input\ICPSR_35206\DS0008\35206-0008-Data.dta", clear

gen Year = 1900
rename TOTPOP TotPop
gen Cattle = DCOWS+OTCOWS +STEER1_2+STEER2_3+STEER30+BULLS+CALVES+HEIFERS

rename FARMVAL Value_Land
rename LIVSTOCK ValueLifeStock
gen Value_Farm = TOTVAL-ValueLifeStock

gen ValueCrops = MISCVAL1+MISCVAL2

rename FARMS Farms
rename FARMSIZE FarmSize
rename FARMOWN FarmOwn
rename FARMLAB ExpenditureLabor

gen FarmSize_09 = FARM12+FARM39 
gen FarmSize_1019 = FARM1019 
gen FarmSize_2049 = FARM2049 
gen FarmSize_5099 = FARM5099 
gen FarmSize_100 = FARM100+FARM175+FARM260 
gen FarmSize_500 = FARM500  
gen FarmSize_1000 =FARM1000


local list TotPop Cattle Value_Land ValueLifeStock ValueCrops Value_Farm Farms FarmSize FarmOwn ///
	FarmSize_09 FarmSize_1019 FarmSize_2049 FarmSize_5099 FarmSize_100 FarmSize_500 FarmSize_1000 ExpenditureLabor
#delimit ;
keep `list'      
	Year FIPS LEVEL STATE COUNTY NAME ;
	
#delimit cr

format FIPS %5.0f
keep if FIPS!=.
duplicates drop FIPS, force

gen FIPS00 = FIPS

save "Create_AgriculturalCensus\temp\test.dta", replace 


use "Create_AgriculturalCensus\Input\T0035.dta", clear
qui tab FIPS00
di `r(r)'
qui tab FIPS35
di `r(r)'
keep if FIPS35!=0&FIPS00!=0

gen Share = F_AREA/AREA00
sort FIPS00

merge m:1 FIPS00 using "Create_AgriculturalCensus\temp\test.dta"

foreach var of local list  {

replace `var' = `var'*Share
}

collapse (sum) `list'  , by(FIPS35 Year)

rename FIPS35 FIPS

merge 1:1 FIPS Year using "Create_AgriculturalCensus\temp\temp.dta"

rename _merge merge_1900

save "Create_AgriculturalCensus\temp\temp.dta", replace




********************************************************************************
*	1910
********************************************************************************
use "Create_AgriculturalCensus\Input\ICPSR_35206\DS0009\35206-0009-Data.dta", clear

gen Year = 1910

rename TOTPOP TotPop
gen Cattle = CATTLE

rename FARMVAL Value_Land 
rename LIVSTOCK ValueLifeStock
gen Value_Farm = TOTVAL-ValueLifeStock

rename FARMS Farms
rename FARMOWN FarmOwn
rename VALPFARM AverageTotalValuePerFarm
rename FAWAGES ExpenditureLabor
rename FEEDEXP ExpenditureFeed
rename CROPVAL ValueCrops

gen FarmSize_09 = FARM02+FARM39 
gen FarmSize_1019 = FARM1019 
gen FarmSize_2049 = FARM2049 
gen FarmSize_5099 = FARM5099 
gen FarmSize_100 = FARM100+FARM175+FARM260 
gen FarmSize_500 = FARM500  
gen FarmSize_1000 =FARM1000


local list TotPop Cattle Value_Land ValueLifeStock Value_Farm Farms  FarmOwn ///
	FarmSize_09 FarmSize_1019 FarmSize_2049 FarmSize_5099 FarmSize_100 FarmSize_500 FarmSize_1000 ExpenditureFeed ExpenditureLabor ValueCrops
	
#delimit ;
keep `list'
	Year FIPS LEVEL STATE COUNTY NAME ;
	
#delimit cr

format FIPS %5.0f
keep if FIPS!=.
duplicates drop FIPS, force

gen FIPS10 = FIPS

save "Create_AgriculturalCensus\temp\test.dta", replace 


use "Create_AgriculturalCensus\Input\T1035.dta", clear
qui tab FIPS10
di `r(r)'
qui tab FIPS35
di `r(r)'
keep if FIPS35!=0&FIPS10!=0

gen Share = F_AREA/AREA10
sort FIPS10

merge m:1 FIPS10 using "Create_AgriculturalCensus\temp\test.dta"

foreach var of local list {

replace `var' = `var'*Share
}

collapse (sum) `list' , by(FIPS35 Year)

rename FIPS35 FIPS
qui tab FIPS
di `r(r)'


merge 1:1 FIPS Year using "Create_AgriculturalCensus\temp\temp.dta"

rename _merge merge_1910

save "Create_AgriculturalCensus\temp\temp.dta", replace



********************************************************************************
*	1920
********************************************************************************
use "Create_AgriculturalCensus\Input\ICPSR_35206\DS0011\35206-0011-Data.dta", clear

gen Year = 1920

rename TOTPOP TotPop
gen Cattle = VAR70

rename VAR1 Farms
rename VAR27 FarmOwn
rename VAR23 Value_Land
rename VAR308 ExpenditureLabor
rename VAR314 ExpenditureFeed
rename VAR26 ValueLifeStock
rename VAR138 ValueCrops

gen Value_Farm =  VAR22-ValueLifeStock


gen FarmSize_09 = VAR7+VAR8
gen FarmSize_1019 = VAR9
gen FarmSize_2049 = VAR10
gen FarmSize_5099 = VAR11
gen FarmSize_100 = VAR12+VAR13+VAR14
gen FarmSize_500 = VAR15
gen FarmSize_1000 =VAR15A+VAR15B



local list TotPop Cattle Value_Land ValueLifeStock Value_Farm Farms  FarmOwn ///
	FarmSize_09 FarmSize_1019 FarmSize_2049 FarmSize_5099 FarmSize_100 FarmSize_500 FarmSize_1000 ExpenditureFeed ExpenditureLabor ValueCrops
	
#delimit ;
keep `list'
	Year FIPS LEVEL STATE COUNTY NAME ;
	
#delimit cr

format FIPS %5.0f
keep if FIPS!=.
duplicates drop FIPS, force

gen FIPS20 = FIPS

save "Create_AgriculturalCensus\temp\test.dta", replace 


use "Create_AgriculturalCensus\Input\T2035.dta", clear
qui tab FIPS20
di `r(r)'
qui tab FIPS35
di `r(r)'
keep if FIPS20!=0&FIPS35!=0

gen Share = F_AREA/AREA20
sort FIPS20

merge m:1 FIPS20 using "Create_AgriculturalCensus\temp\test.dta"

foreach var of local list    {
replace `var' = `var'*Share
}

collapse (sum) `list' , by(FIPS35 Year)

rename FIPS35 FIPS

merge 1:1 FIPS Year using "Create_AgriculturalCensus\temp\temp.dta"

rename _merge merge_1920

save "Create_AgriculturalCensus\temp\temp.dta", replace





********************************************************************************
*	1925
********************************************************************************
use "Create_AgriculturalCensus\Input\ICPSR_35206\DS0012\35206-0012-Data.dta", clear

gen Year = 1925

rename VAR1 TotPop
gen Cattle = VAR207

rename VAR2 Farms
rename VAR17 FarmOwn
rename VAR74 FarmSize
rename VAR178 ExpenditureFeed
rename VAR182 ExpenditureLabor
rename VAR125 Value_Land
rename VAR198 ValueLifeStock
rename VAR257 ValueCrops

gen Value_Farm = VAR126-ValueLifeStock

gen FarmSize_09 = VAR3+VAR4
gen FarmSize_1019 = VAR5
gen FarmSize_2049 = VAR6
gen FarmSize_5099 = VAR7
gen FarmSize_100 = VAR8+VAR9+VAR10
gen FarmSize_500 = VAR11
gen FarmSize_1000 =VAR12+VAR13



local list TotPop Cattle Value_Land ValueLifeStock Value_Farm Farms FarmSize FarmOwn ///
	FarmSize_09 FarmSize_1019 FarmSize_2049 FarmSize_5099 FarmSize_100 FarmSize_500 FarmSize_1000 ExpenditureFeed ExpenditureLabor ValueCrops
	
#delimit ;
keep `list'
	Year FIPS LEVEL STATE COUNTY NAME ;
	
#delimit cr

format FIPS %5.0f
keep if FIPS!=.
duplicates drop FIPS, force

gen FIPS25 = FIPS

save "Create_AgriculturalCensus\temp\test.dta", replace 


use "Create_AgriculturalCensus\Input\T2535.dta", clear
qui tab FIPS25
di `r(r)'
qui tab FIPS35
di `r(r)'
keep if FIPS25!=0&FIPS35!=0

gen Share = F_AREA/AREA25
sort FIPS25

merge m:1 FIPS25 using "Create_AgriculturalCensus\temp\test.dta"

foreach var of local list {
replace `var' = `var'*Share
}

collapse (sum) `list'  , by(FIPS35 Year)

rename FIPS35 FIPS

merge 1:1 FIPS Year using "Create_AgriculturalCensus\temp\temp.dta"

rename _merge merge_1925

save "Create_AgriculturalCensus\temp\temp.dta", replace





********************************************************************************
*	1930
********************************************************************************
use "Create_AgriculturalCensus\Input\ICPSR_35206\DS0013\35206-0013-Data.dta", clear

gen Year = 1930

rename VAR1 TotPop
gen Cattle = VAR192

rename VAR120 Value_Farm
rename VAR121 Value_Land
rename VAR2 Farms
rename VAR11 FarmSize
rename VAR22 FarmOwn
rename VAR1001 ExpenditureFeed
rename VAR1007 ExpenditureLabor
rename VAR1113 ValueLifeStock
rename VAR1115 ValueSoldAnimals
rename VAR1119 ValueSoldCrops

gen FarmSize_09 = VAR85+VAR86
gen FarmSize_1019 = VAR87
gen FarmSize_2049 = VAR88
gen FarmSize_5099 = VAR89
gen FarmSize_100 = VAR90+VAR91+VAR92
gen FarmSize_500 = VAR93
gen FarmSize_1000 =VAR94+VAR95



local list TotPop Cattle Value_Land ValueLifeStock Value_Farm Farms FarmSize FarmOwn ValueSoldCrops ValueSoldAnimals ///
	FarmSize_09 FarmSize_1019 FarmSize_2049 FarmSize_5099 FarmSize_100 FarmSize_500 FarmSize_1000 ExpenditureFeed ExpenditureLabor 
	
#delimit ;
keep `list'
	Year FIPS LEVEL STATE COUNTY NAME ;
	
#delimit cr

format FIPS %5.0f
keep if FIPS!=.
duplicates drop FIPS, force

gen FIPS30 = FIPS

save "Create_AgriculturalCensus\temp\test.dta", replace 


use "Create_AgriculturalCensus\Input\T3035.dta", clear
qui tab FIPS30
di `r(r)'
qui tab FIPS35
di `r(r)'

keep if FIPS30!=0&FIPS35!=0

gen Share = F_AREA/AREA30
sort FIPS30

merge m:1 FIPS30 using "Create_AgriculturalCensus\temp\test.dta"

foreach var of local list     {
replace `var' = `var'*Share
}

collapse (sum) `list'    , by(FIPS35 Year)

rename FIPS35 FIPS

merge 1:1 FIPS Year using "Create_AgriculturalCensus\temp\temp.dta"

rename _merge merge_1930

save "Create_AgriculturalCensus\temp\temp.dta", replace



********************************************************************************
*	1935
********************************************************************************
use "Create_AgriculturalCensus\Input\ICPSR_35206\DS0015\35206-0015-Data.dta", clear

gen Year = 1935

rename VAR1 TotPop
gen Cattle = VAR105

rename VAR19 Value_Farm
rename VAR2 Farms
rename VAR5 FarmOwn
rename VAR11 FarmSize

gen FarmSize_09 = VAR201+VAR202
gen FarmSize_1019 = VAR203
gen FarmSize_2049 = VAR204+VAR205
gen FarmSize_5099 = VAR206+VAR207
gen FarmSize_100 = VAR208+VAR209+VAR210+VAR211+VAR212+VAR213+VAR214
gen FarmSize_500 = VAR215+VAR216
gen FarmSize_1000 =VAR218



local list TotPop Cattle Value_Farm Farms FarmSize FarmOwn ///
	FarmSize_09 FarmSize_1019 FarmSize_2049 FarmSize_5099 FarmSize_100 FarmSize_500 FarmSize_1000 FarmSize_*
	
#delimit ;
keep `list'
	Year FIPS LEVEL STATE COUNTY NAME ;
	
#delimit cr

format FIPS %5.0f
keep if FIPS!=.
duplicates drop FIPS, force
merge 1:1 FIPS Year using "Create_AgriculturalCensus\temp\temp.dta"

rename _merge merge_1935

save "Create_AgriculturalCensus\temp\temp.dta", replace




********************************************************************************
*	1940
********************************************************************************

use "Create_AgriculturalCensus\Input\ICPSR_35206\DS0018\35206-0018-Data.dta", clear

gen Year = 1940

rename VAR1 TotPop
gen Cattle = VAR198

rename VAR29 Value_Farm
rename VAR4 Farms
rename VAR40 FarmOwn
rename VAR8 FarmSize
rename VAR560 ExpenditureLabor
rename VAR568 ExpenditureFeed
rename VAR2002 ValueLifeStock
rename VAR2189 ValueSoldCrops
rename VAR2175 ValueSoldAnimals
gen Value_Land = Value_Farm - VAR31


gen FarmSize_09 = VAR111
gen FarmSize_1019 = VAR116
gen FarmSize_2049 = VAR115-VAR116+VAR117
gen FarmSize_5099 = VAR118+VAR119
gen FarmSize_100 = VAR120+VAR121+VAR122+VAR123+VAR124+VAR125+VAR126
gen FarmSize_500 = VAR127+VAR128
gen FarmSize_1000 =VAR129

format FIPS %5.0f
keep if FIPS!=.


local list TotPop Cattle Value_Land ValueLifeStock Value_Farm Farms FarmSize FarmOwn ///
	FarmSize_09 FarmSize_1019 FarmSize_2049 FarmSize_5099 FarmSize_100 FarmSize_500 FarmSize_1000 ExpenditureFeed ExpenditureLabor ValueSoldCrops ValueSoldAnimals
desc `list'  Year LEVEL STATE COUNTY 
#delimit ;
collapse (max) `list'
	Year LEVEL STATE COUNTY  , by(FIPS);
	
#delimit cr
 
merge 1:1 FIPS Year using "Create_AgriculturalCensus\temp\temp.dta"

rename _merge merge_1940

duplicates tag COUNTY STATE Year, gen(tag)

bysort tag: egen max_farms=max(Farms)
drop if tag==1&Farms<max_farms

drop tag max_farms
save "Create_AgriculturalCensus\temp\temp.dta", replace





********************************************************************************
*	1945
********************************************************************************

use "Create_AgriculturalCensus\Input\ICPSR_35206\DS0020\35206-0020-Data.dta", clear

gen Year = 1945
rename TOTPOP40 TotPop
gen Cattle = VAR464

rename VAR456 ValueLifeStock
rename VAR39 Value_Farm
rename VAR2 Farms
rename VAR7 FarmSize
rename VAR556 FarmOwn
rename VAR119 ExpenditureLabor
rename VAR524 ExpenditureFeed
rename VAR127 ValueSoldCrops
rename VAR502 ValueSoldAnimals

gen FarmSize_09 = VAR667+VAR668
gen FarmSize_1029 = VAR669
gen FarmSize_2949 = VAR670
gen FarmSize_5099 = VAR671+VAR672
gen FarmSize_100 = VAR673+VAR674+VAR675+VAR676+VAR677+VAR678
gen FarmSize_500 = VAR679+VAR680
gen FarmSize_1000 =VAR681


local list TotPop Cattle Value_Farm ValueLifeStock Farms FarmSize FarmOwn ///
	FarmSize_09 FarmSize_1029 FarmSize_2949 FarmSize_5099 FarmSize_100 FarmSize_500 FarmSize_1000 ExpenditureLabor ExpenditureFeed ValueSoldCrops ValueSoldAnimals
	
#delimit ;
keep `list'
	Year FIPS LEVEL STATE COUNTY NAME ;
	
#delimit cr

format FIPS %5.0f
keep if FIPS!=.
duplicates drop FIPS, force
merge 1:1 FIPS Year using "Create_AgriculturalCensus\temp\temp.dta"

rename _merge merge_1945

save "Create_AgriculturalCensus\temp\temp.dta", replace




********************************************************************************
*	1950
*******************************************************************************

use "Create_AgriculturalCensus\Input\ICPSR_35206\DS0021\35206-0021-Data.dta", clear

gen Year = 1950

rename TOTPOP TotPop
gen Cattle = VAR307

rename VAR298 ValueLifeStock
rename VAR9 FarmSize
rename VAR129 FarmOwn
rename VAR145 GrazingPermit
rename VAR285 ExpenditureLabor 
rename VAR287 ExpenditureFeed
rename VAR1 Farms
rename VAR443 ValueSoldCrops
rename VAR387 ValueSoldAnimals
gen Value_Farm = Farms*VAR10

gen FarmSize_09 = VAR100
gen FarmSize_1029 = VAR103
gen FarmSize_2949 = VAR104
gen FarmSize_5099 = VAR105+VAR106
gen FarmSize_100 = VAR107+VAR108+VAR109+VAR110+VAR111
gen FarmSize_500 = VAR112
gen FarmSize_1000 =VAR113

local list TotPop Cattle Value_Farm ValueLifeStock Farms FarmSize FarmOwn ///
	FarmSize_09 FarmSize_1029 FarmSize_2949 FarmSize_5099 FarmSize_100 FarmSize_500 FarmSize_1000 ExpenditureLabor ExpenditureFeed GrazingPermit ValueSoldCrops ValueSoldAnimals
	
#delimit ;
keep `list'
	Year FIPS LEVEL STATE COUNTY NAME ;
	
#delimit cr

format FIPS %5.0f
keep if FIPS!=.
duplicates drop FIPS, force
merge 1:1 FIPS Year using "Create_AgriculturalCensus\temp\temp.dta"

rename _merge merge_1950

save "Create_AgriculturalCensus\temp\temp.dta", replace



********************************************************************************
*	1954
*******************************************************************************
use "Create_AgriculturalCensus\Input\ICPSR_35206\DS0025\35206-0025-Data.dta", clear

gen Year = 1954

rename TOTPOP50 TotPop
gen Cattle = VAR364

rename VAR9 FarmSize
rename VAR103 FarmOwn
rename VAR319 ExpenditureFeed
rename VAR311 ExpenditureLabor
rename VAR1 Farms
rename VAR231 ValueSoldCrops
rename VAR450 ValueSoldAnimals
gen Value_Farm = Farms*VAR10


gen FarmSize_09 = VAR187
gen FarmSize_1029 = VAR190
gen FarmSize_2949 = VAR191
gen FarmSize_5099 = VAR192+VAR193
gen FarmSize_100 = VAR194+VAR195+VAR196+VAR197+VAR198
gen FarmSize_500 = VAR199
gen FarmSize_1000 =VAR200


local list TotPop Cattle Value_Farm  Farms FarmSize FarmOwn ///
	FarmSize_09 FarmSize_1029 FarmSize_2949 FarmSize_5099 FarmSize_100 FarmSize_500 FarmSize_1000 ExpenditureLabor ExpenditureFeed ValueSoldAnimals ValueSoldCrops
	
#delimit ;
keep `list'
	Year LEVEL STATE COUNTY NAME ;
	
#delimit cr


duplicates drop COUNTY STATE, force
merge 1:m COUNTY STATE  Year using "Create_AgriculturalCensus\temp\temp.dta"

rename _merge merge_1954

save "Create_AgriculturalCensus\temp\temp.dta", replace




********************************************************************************
*	1959
*******************************************************************************
use "Create_AgriculturalCensus\Input\ICPSR_35206\DS0027\35206-0027-Data.dta", clear

gen Year = 1959

rename TOTPOP60 TotPop
gen Cattle = VAR716

rename VAR6 FarmSize
rename VAR189 FarmOwn
rename VAR688 ExpenditureFeed
rename VAR697 ExpenditureLabor
rename VAR1 Farms
rename VAR786 ValueSoldAnimals
rename VAR493 ValueSoldCrops
gen Value_Farm = Farms*VAR7

gen FarmSize_09 = VAR137
gen FarmSize_1049 = VAR138
gen FarmSize_5099 = VAR139+VAR140
gen FarmSize_100 = VAR141+VAR142+VAR143+VAR144+VAR145
gen FarmSize_500 = VAR146
gen FarmSize_1000 =VAR147


local list TotPop Cattle Value_Farm  Farms FarmSize FarmOwn ///
	FarmSize_09 FarmSize_1049  FarmSize_5099 FarmSize_100 FarmSize_500 FarmSize_1000 ExpenditureLabor ExpenditureFeed ValueSoldAnimals ValueSoldCrops 
	
#delimit ;
keep `list'
	Year LEVEL STATE COUNTY NAME ;
	
#delimit cr



duplicates drop COUNTY STATE, force
merge 1:m COUNTY STATE Year using "Create_AgriculturalCensus\temp\temp.dta"
rename _merge merge_1959

save "Create_AgriculturalCensus\temp\temp.dta", replace




********************************************************************************
*	1964
********************************************************************************


use "Create_AgriculturalCensus\Input\ICPSR_35206\DS0030\35206-0030-Data.dta", clear

gen Year = 1964

rename TOTPOP60 TotPop
gen Cattle = VAR680

rename VAR5 FarmSize
rename VAR145 FarmOwn
rename VAR646 ExpenditureFeed
rename VAR677 ExpenditureLabor
rename VAR1 Farms
gen Value_Farm = Farms*VAR6

gen ValueSoldAnimals =VAR747+VAR774+VAR782+VAR785+VAR856 
rename VAR375 ValueSoldCrops


gen FarmSize_09 = VAR93
gen FarmSize_1049 = VAR94
gen FarmSize_5099 = VAR95+VAR96
gen FarmSize_100 = VAR97+VAR98+VAR99+VAR100+VAR101
gen FarmSize_500 = VAR102
gen FarmSize_1000 =VAR103+VAR104

local list TotPop Cattle Value_Farm  Farms FarmSize FarmOwn ///
	FarmSize_09 FarmSize_1049  FarmSize_5099 FarmSize_100 FarmSize_500 FarmSize_1000 ExpenditureLabor ExpenditureFeed ValueSoldAnimals ValueSoldCrops
	
#delimit ;
keep `list'
	Year FIPS LEVEL STATE COUNTY NAME ;
	
#delimit cr


duplicates drop COUNTY STATE, force
duplicates drop FIPS, force

merge 1:1 FIPS COUNTY STATE Year using "Create_AgriculturalCensus\temp\temp.dta"

rename _merge merge_1964

save "Create_AgriculturalCensus\temp\temp.dta", replace




********************************************************************************
*	1969
********************************************************************************
use "Create_AgriculturalCensus\Input\ICPSR_35206\DS0033\35206-0033-Data.dta", clear

gen Year = 1969

replace FIPS = 32025 if FIPS==32510
replace COUNTY = 250 if FIPS == 32025
gen Cattle = ITEM07006

rename ITEM01003 FarmSize
rename ITEM02004 FarmOwn
rename ITEM01001 Farms

gen Value_Farm = ITEM01006*1000
gen ExpenditureFeed = ITEM05015*1000
gen ExpenditureLabor = ITEM05045*1000
gen ValueSoldCrops = ITEM03025*1000


gen FarmSize_09 = ITEM01009
gen FarmSize_1049 = ITEM01010
gen FarmSize_5099 = ITEM01011+ITEM01012
gen FarmSize_100 = ITEM01013+ITEM01014+ITEM01015+ITEM01016+ITEM01017
gen FarmSize_500 = ITEM01018
gen FarmSize_1000 =ITEM01019+ITEM01020


drop if Farms==40000000000
drop if ExpenditureFeed>=400000000&ExpenditureFeed!=.

local list Cattle Value_Farm  Farms FarmSize FarmOwn ///
	FarmSize_09 FarmSize_1049  FarmSize_5099 FarmSize_100 FarmSize_500 FarmSize_1000 ExpenditureLabor ExpenditureFeed ValueSoldCrops
	
#delimit ;
keep `list'
	Year FIPS LEVEL STATE COUNTY NAME ;
	
#delimit cr

duplicates drop COUNTY STATE, force
duplicates drop FIPS, force

merge 1:1 FIPS COUNTY STATE Year using "Create_AgriculturalCensus\temp\temp.dta"

rename _merge merge_1969

save "Create_AgriculturalCensus\temp\temp.dta", replace





********************************************************************************
*	1974
*******************************************************************************
use "Create_AgriculturalCensus\Input\ICPSR_35206\DS0036\35206-0036-Data.dta", clear

replace FIPS = 32025 if FIPS==32510
replace COUNTY = 250 if FIPS == 32025

gen Year = 1974
gen Cattle = ITEM07006

rename ITEM01003 FarmSize
rename ITEM02004 FarmOwn
rename ITEM01001 Farms
gen Value_Farm = ITEM01006*1000

gen ExpenditureFeed = ITEM05015*1000
gen ExpenditureLabor = ITEM05045*1000
gen ValueSoldCrops = ITEM03025*1000

gen FarmSize_09 = ITEM01009
gen FarmSize_1049 = ITEM01010
gen FarmSize_5099 = ITEM01011+ITEM01012
gen FarmSize_100 = ITEM01013+ITEM01014+ITEM01015+ITEM01016+ITEM01017
gen FarmSize_500 = ITEM01018
gen FarmSize_1000 =ITEM01019+ITEM01020



local list Cattle Value_Farm  Farms FarmSize FarmOwn ///
	FarmSize_09 FarmSize_1049 FarmSize_5099 FarmSize_100 FarmSize_500 FarmSize_1000 ExpenditureLabor ExpenditureFeed ValueSoldCrops
	
#delimit ;
keep `list'
	Year FIPS LEVEL STATE COUNTY NAME ;
	
#delimit cr

duplicates drop COUNTY STATE, force
duplicates drop FIPS, force

merge 1:1 FIPS COUNTY STATE Year using "Create_AgriculturalCensus\temp\temp.dta"
rename _merge merge_1974

save "Create_AgriculturalCensus\temp\temp.dta", replace



********************************************************************************
*	1978
*******************************************************************************
use "Create_AgriculturalCensus\Input\ICPSR_35206\DS0039\35206-0039-Data.dta", clear

replace FIPS = 32025 if FIPS==32510
replace COUNTY = 250 if FIPS == 32025

gen Year = 1978

gen Cattle = ITEM01038

rename ITEM01003 FarmSize
rename ITEM10005 FarmOwn
rename ITEM01001 Farms
gen Value_Farm = ITEM01004*Farms
gen ExpenditureFeed = ITEM03007*1000
gen ExpenditureLabor = ITEM03029*1000 
gen ValueSoldAnimals =(ITEM11059+ITEM12034+ITEM12051+ITEM13016+ITEM13021+ITEM14027)*1000
gen ValueSoldCrops = ITEM01021*1000

rename ITEM36001 GrazingPermit

gen FarmSize_09 = ITEM01007
gen FarmSize_1049 = ITEM01008
gen FarmSize_50179 = ITEM01009
gen FarmSize_180499 = ITEM01010
gen FarmSize_500 = ITEM01011
gen FarmSize_1000 =ITEM01012


local list Cattle Value_Farm  Farms FarmSize FarmOwn ///
	FarmSize_09 FarmSize_1049 FarmSize_50179 FarmSize_180499 FarmSize_500 FarmSize_1000 ExpenditureLabor ExpenditureFeed GrazingPermit ValueSoldAnimals ValueSoldCrops

#delimit ;
keep `list'
	Year FIPS LEVEL STATE COUNTY NAME ;
	
#delimit cr


duplicates drop COUNTY STATE, force
duplicates drop FIPS, force

merge 1:1 FIPS COUNTY STATE Year using "Create_AgriculturalCensus\temp\temp.dta"

rename _merge merge_1978

save "Create_AgriculturalCensus\temp\temp.dta", replace



********************************************************************************
*	1982
*******************************************************************************
use "Create_AgriculturalCensus\Input\ICPSR_35206\DS0040\35206-0040-Data.dta", clear

replace FIPS = 32025 if FIPS==32510
replace COUNTY = 250 if FIPS == 32025

gen Year = 1982
drop FLAG*

gen Cattle = ITEM01038

rename ITEM01003 FarmSize
rename ITEM10005 FarmOwn
rename ITEM01001 Farms
gen Value_Farm = Farms*ITEM01004

gen ExpenditureFeed = ITEM03007*1000
gen ExpenditureLabor = ITEM03029*1000 
gen ValueSoldAnimals =(ITEM11059+ITEM12034+ITEM12051+ITEM13016+ITEM13021+ITEM14027)*1000
gen ValueSoldCrops  = ITEM01021*1000

rename ITEM36001 GrazingPermit

gen FarmSize_09 = ITEM01007
gen FarmSize_1049 = ITEM01008
gen FarmSize_50179 = ITEM01009
gen FarmSize_180499 = ITEM01010
gen FarmSize_500 = ITEM01011
gen FarmSize_1000 =ITEM01012

local list Cattle Value_Farm  Farms FarmSize FarmOwn ///
	FarmSize_09 FarmSize_1049 FarmSize_50179 FarmSize_180499 FarmSize_500 FarmSize_1000 ExpenditureLabor ExpenditureFeed GrazingPermit ValueSoldAnimals ValueSoldCrops

#delimit ;
keep `list'
	Year FIPS LEVEL STATE COUNTY NAME ;
	
#delimit cr


duplicates drop COUNTY STATE, force
duplicates drop FIPS, force

merge 1:1 FIPS COUNTY STATE Year using "Create_AgriculturalCensus\temp\temp.dta"

rename _merge merge_1982

save "Create_AgriculturalCensus\temp\temp.dta", replace




********************************************************************************
*	1987
*******************************************************************************
use "Create_AgriculturalCensus\Input\ICPSR_35206\DS0041\35206-0041-Data.dta", clear

replace FIPS = 32025 if FIPS==32510
replace COUNTY = 250 if FIPS == 32025

gen Year = 1987
drop FLAG*

rename ITEM01038 Cattle
rename ITEM01003 FarmSize
rename ITEM10005 FarmOwn
rename ITEM01001 Farms
gen Value_Farm = Farms*ITEM01004

gen ExpenditureFeed = ITEM03007*1000
gen ExpenditureLabor = ITEM03029*1000 
gen ValueSoldAnimals =(ITEM11059+ITEM12034+ITEM12051+ITEM13016+ITEM13021+ITEM14027)*1000
gen ValueSoldCrops  = ITEM01021*1000

rename ITEM36001 GrazingPermit

gen FarmSize_09 = ITEM01007
gen FarmSize_1049 = ITEM01008
gen FarmSize_50179 = ITEM01009
gen FarmSize_180499 = ITEM01010
gen FarmSize_500 = ITEM01011
gen FarmSize_1000 =ITEM01012


local list Cattle Value_Farm  Farms FarmSize FarmOwn ///
	FarmSize_09 FarmSize_1049 FarmSize_50179 FarmSize_180499 FarmSize_500 FarmSize_1000 ExpenditureLabor ExpenditureFeed GrazingPermit ValueSoldAnimals ValueSoldCrops

#delimit ;
keep `list'
	Year FIPS LEVEL STATE COUNTY NAME ;
	
#delimit cr

duplicates drop COUNTY STATE, force
duplicates drop FIPS, force

merge 1:1 FIPS COUNTY STATE Year using "Create_AgriculturalCensus\temp\temp.dta"

rename _merge merge_1987

save "Create_AgriculturalCensus\temp\temp.dta", replace



********************************************************************************
*	1992
*******************************************************************************
use "Create_AgriculturalCensus\Input\ICPSR_35206\DS0042\35206-0042-Data.dta", clear

replace FIPS = 32025 if FIPS==32510
replace COUNTY = 250 if FIPS == 32025

gen Year = 1992
drop FLAG*

rename ITEM010040 Cattle
rename ITEM010003 FarmSize
rename ITEM110005 FarmOwn
rename ITEM010001 Farms
gen Value_Farm = ITEM060005*1000

gen ValueSoldAnimals =(ITEM140087+ITEM150033+ITEM150050+ITEM160027+ITEM020071)*1000
gen ValueSoldCrops  = ITEM120013*1000
gen ExpenditureFeed = ITEM030007*1000
gen ExpenditureLabor = ITEM030029*1000 

rename ITEM390001 GrazingPermit

gen FarmSize_09 = ITEM010007
gen FarmSize_1049 = ITEM010008
gen FarmSize_50179 = ITEM010009
gen FarmSize_180499 = ITEM010010
gen FarmSize_500 = ITEM010011
gen FarmSize_1000 =ITEM010012


local list Cattle Value_Farm  Farms FarmSize FarmOwn ///
	FarmSize_09 FarmSize_1049 FarmSize_50179 FarmSize_180499 FarmSize_500 FarmSize_1000 ExpenditureLabor ExpenditureFeed GrazingPermit ValueSoldCrops ValueSoldAnimals

#delimit ;
keep `list'
	Year FIPS LEVEL STATE COUNTY NAME ;
	
#delimit cr

duplicates drop COUNTY STATE, force
duplicates drop FIPS, force

merge 1:1 FIPS COUNTY STATE Year using "Create_AgriculturalCensus\temp\temp.dta"

rename _merge merge_1992

save "Create_AgriculturalCensus\temp\temp.dta", replace



********************************************************************************
*	1997
*******************************************************************************
use "Create_AgriculturalCensus\Input\ICPSR_35206\DS0043\35206-0043-Data.dta", clear

replace FIPS = 32025 if FIPS==32510
replace COUNTY = 250 if FIPS == 32025

gen Year = 1997
drop FLAG*

rename ITEM12188 Cattle
rename ITEM01001 Farms
rename ITEM01003 FarmSize
rename ITEM11005 FarmOwn
gen Value_Farm = ITEM06005*1000
sum Value_Farm

gen ExpenditureFeed = ITEM03007*1000
gen ExpenditureLabor = ITEM03029*1000 
gen ValueSoldAnimals =(ITEM15033+ITEM15050+ITEM16027+ITEM17021+ITEM14087)*1000
gen ValueSoldCrops  = ITEM01022*1000

rename ITEM39001 GrazingPermit

gen FarmSize_09 = ITEM01008
gen FarmSize_1049 = ITEM01009
gen FarmSize_50179 = ITEM01010
gen FarmSize_180499 = ITEM01011
gen FarmSize_500 = ITEM01012
gen FarmSize_1000 =ITEM01013


local list Cattle Value_Farm  Farms FarmSize FarmOwn ///
	FarmSize_09 FarmSize_1049 FarmSize_50179 FarmSize_180499 FarmSize_500 FarmSize_1000 ExpenditureLabor ExpenditureFeed GrazingPermit ValueSoldCrops ValueSoldAnimals

#delimit ;
collapse (max) `list'
	Year LEVEL STATE  COUNTY  , by(FIPS);	
#delimit cr


merge 1:1 FIPS COUNTY STATE Year using "Create_AgriculturalCensus\temp\temp.dta"

rename _merge merge_1997

save "Create_AgriculturalCensus\temp\temp.dta", replace



********************************************************************************
*	2002
*******************************************************************************
use "Create_AgriculturalCensus\Input\ICPSR_35206\DS0044\35206-0044-Data.dta", clear

replace FIPS = 32025 if FIPS==32510
replace COUNTY = 250 if FIPS == 32025

gen Year = 2002

rename ITEM11003 Cattle
rename ITEM01001 Farms
rename ITEM01003 FarmSize
rename ITEM11005 FarmOwn
gen Value_Farm = ITEM08009*1000
sum Value_Farm, det

gen ValueSoldAnimals =(ITEM11117+ITEM12049)*1000
gen ValueSoldCrops  = ITEM01022*1000
gen ExpenditureFeed = ITEM03007*1000
gen ExpenditureLabor = ITEM03049*1000 

egen FS = rowtotal(ITEM08076 ITEM08104 ITEM08124)
replace FarmSize = FS/Farms if FarmSize==.

gen FarmSize_09 = ITEM01008
gen FarmSize_1049 = ITEM01009
gen FarmSize_50179 = ITEM01010
gen FarmSize_180499 = ITEM01011
gen FarmSize_500 = ITEM01012
gen FarmSize_1000 =ITEM01013


local list Cattle Value_Farm  Farms FarmSize FarmOwn ///
	FarmSize_09 FarmSize_1049 FarmSize_50179 FarmSize_180499 FarmSize_500 FarmSize_1000 ExpenditureLabor ExpenditureFeed ValueSoldCrops ValueSoldAnimals

#delimit ;
keep `list'
	Year FIPS LEVEL STATE COUNTY NAME ;
	
#delimit cr

duplicates drop COUNTY STATE, force
duplicates drop FIPS, force

merge 1:1 FIPS COUNTY STATE Year using "Create_AgriculturalCensus\temp\temp.dta"

rename _merge merge_2002

save "Create_AgriculturalCensus\temp\temp.dta", replace




********************************************************************************
*	2007
********************************************************************************
use "Create_AgriculturalCensus\Input\ICPSR_35206\DS0045\35206-0045-Data.dta", clear

replace FIPS = 32025 if FIPS==32510
replace COUNTY = 250 if FIPS == 32025

gen Year = 2007

rename DATA11_3 Cattle
rename DATA1_1 Farms
rename DATA1_3 FarmSize
rename DATA46_9 FarmOwn

gen Value_Farm = DATA8_9*1000
sum Value_Farm, det

egen FS = rowtotal(DATA8_76 DATA8_104 DATA8_124)
replace FarmSize = FS/Farms if FarmSize==.


gen ExpenditureFeed = DATA3_33*1000
gen ExpenditureLabor = DATA3_49*1000 
gen ValueSoldCrops  = DATA1_22*1000
gen ValueSoldAnimals =(DATA11_117+DATA12_49)*1000


gen FarmSize_09 = DATA1_8
gen FarmSize_1049 = DATA1_9
gen FarmSize_50179 = DATA1_10
gen FarmSize_180499 = DATA1_11
gen FarmSize_500 = DATA1_12
gen FarmSize_1000 =DATA1_13


local list Cattle Value_Farm  Farms FarmSize FarmOwn ///
	FarmSize_09 FarmSize_1049 FarmSize_50179 FarmSize_180499 FarmSize_500 FarmSize_1000 ExpenditureLabor ExpenditureFeed  ValueSoldAnimals ValueSoldCrops

#delimit ;
keep `list'
	Year FIPS LEVEL STATE COUNTY NAME ;
	
#delimit cr


duplicates drop COUNTY STATE, force
duplicates drop FIPS, force

merge 1:1 FIPS COUNTY STATE Year using "Create_AgriculturalCensus\temp\temp.dta"

rename _merge merge_2007

save "Create_AgriculturalCensus\temp\temp.dta", replace




*** cleanup: 

keep if LEVEL==1

drop if FarmSize==450000 //Only one observation, does not make a diff and is only one farm
sort FIPS Year
	
save "Create_AgriculturalCensus\Output\Census_Agri.dta", replace

******




tab Year if Value_Land!=.

gen AverageTotalValuePerFarm_Comp = (Value_Farm+ValueLifeStock)/Farms
replace AverageTotalValuePerFarm_Comp = Value_Farm/Farms if ValueLifeStock==.

gen TotalValue = Value_Farm+ValueLifeStock
replace TotalValue = Value_Farm if ValueLifeStock==.

gen ValueSoldCrops_Comp = ValueSoldCrops
replace ValueSoldCrops_Comp = ValueCrops if Year==1900|Year==1910|Year==1920|Year==1925

gen ValueSoldAnimals_Comp = ValueSoldAnimals
replace ValueSoldAnimals_Comp = ValueLifeStock if Year==1920|Year==1925

gen FarmIncome = ValueSoldCrops_Comp+ValueSoldAnimals_Comp
gen FarmIncome_Farm = FarmIncome/Farms
gen FS_10 = FarmSize_09

gen FS_50 = FarmSize_1049
replace FS_50 = FarmSize_1029+FarmSize_2949 if FS_50==.
replace FS_50 = FarmSize_1019+FarmSize_2049 if FS_50==.

gen FS_100 = FarmSize_100
gen FS_500 = FarmSize_500
gen FS_1000 = FarmSize_1000
gen OwnershipRate = FarmOwn/Farms

********************************************************************************
********************************************************************************
*labels: 
********************************************************************************
********************************************************************************
la var FS_10 "Number of farms less than 10 acres"
la var Farms "Farms, Number"
la var FarmSize "Average Farm Size"
la var Cattle "Cattle, Number"
la var FarmOwn "Farms Owned by Operator, Number"
la var Value_Farm "Value of Farms, exlc. Lifestock"
la var TotPop "Total Population"
la var ValueLifeStock "Value of Life Stock"
la var Value_Land "Value of Land"
la var ExpenditureLabor "Expenditures for Labor"
la var ExpenditureFeed "Expenditures for Feed"
la var OwnershipRate "Ownership Rate"


drop merge_*

****
save "Create_AgriculturalCensus\Output\Census_Agri.dta", replace


****


use  "Create_AgriculturalCensus\Output\Census_Agri.dta", clear
duplicates drop FIPS Year, force

	use "Create_AgriculturalCensus\Input\Treatment.dta", clear
	
	destring FIPS, replace
	
	bysort FIPS: egen CountyArea = sum(F_AREA)

	bysort FIPS: egen Historic_Grazing = max(HG)
	
	gen Grazing_Area_Share = F_AREA/CountyArea
	replace Grazing_Area_Share = 0 if HG==0
	
	collapse (sum) Grazing_Area_Share (max) Historic_Grazing CountyArea , by(FIPS)
	rename FIPS35 FIPS
	
	merge 1:m FIPS using "Create_AgriculturalCensus\Output\Census_Agri.dta"
	
	keep if _merge==3
	drop _merge


save "Create_AgriculturalCensus\Output\Census_Agri_All.dta", replace



use "Create_AgriculturalCensus\Output\Census_Agri_All.dta", clear


gen TGA_State = (US_State==61|US_State==62|US_State==63|US_State==64|US_State==65|US_State==66|US_State==67|US_State==68|US_State==72)
gen Comp_State = (US_State==73|US_State==49|US_State==53|US_State==32|US_State==35|US_State==36|US_State==37|US_State==71)

keep if TGA_State==1|Comp_State==1


* Final outcome variables
gen lnAVF_C = log(AverageTotalValuePerFarm_Comp+1)
gen lnCF = log(Cattle/Farms+1)
gen lnExpLab = log(ExpenditureLabor+1)

**********************************************************************

gen TGA = (Year>=1940)
gen HG_Dummy = (Historic_Grazing==1)

replace HG_Dummy=0 if TGA_State==0

tab STATE HG_Dummy 

cap drop _merge

*** labels
la var lnAVF_C "log(Average value of farm)"
la var TGA "Post TGA"
***


save "Create_AgriculturalCensus\Output\AgriCensusFinal.dta", replace


stop

use "Create_AgriculturalCensus\Output\AgriCensusFinal.dta", clear
cap drop _merge

merge m:1 FIPS using "Input\Erosion_AC.dta"
replace Red_Erosion = . if _merge!=3
cap drop _merge

save "Create_AgriculturalCensus\Output\AgriCensusFinal.dta", replace



** Exogeneity Check for all variables in 1920 1925 1930 1935 :
keep if Year>=1890
keep if TGA_State==1

gen Partial_Erosion_Info = 1 if FIPS==8001|FIPS==8005|FIPS==8009|FIPS==8011|FIPS==8013|FIPS==8017|FIPS==8025|FIPS==8031|FIPS==8035|FIPS==8039|FIPS==8041|FIPS==8043|FIPS==8055|FIPS==8059|FIPS==8061|FIPS==8063|FIPS==8069|FIPS==8071|FIPS==8073|FIPS==8075|FIPS==8087|FIPS==8089|FIPS==8095|FIPS==8099|FIPS==8101|FIPS==8115|FIPS==8119|FIPS==8121|FIPS==8123|FIPS==8125

*twoway (kdensity Distance_Grazing_Treated ) (kdensity Mean_Dist)
gen HG_TGA = HG_Dummy*TGA

* For IV
gen RE = Red_Erosion
gen RE_TGA = RE*TGA



save "Create_AgriculturalCensus\Output\AgriCensus_Analysis.dta", replace

*****************



*** More states:

use "Create_AgriculturalCensus\Output\AgriCensusFinal.dta", clear

gen Partial_Erosion_Info = 1 if FIPS==8001|FIPS==8005|FIPS==8009|FIPS==8011|FIPS==8013|FIPS==8017|FIPS==8025|FIPS==8031|FIPS==8035|FIPS==8039|FIPS==8041|FIPS==8043|FIPS==8055|FIPS==8059|FIPS==8061|FIPS==8063|FIPS==8069|FIPS==8071|FIPS==8073|FIPS==8075|FIPS==8087|FIPS==8089|FIPS==8095|FIPS==8099|FIPS==8101|FIPS==8115|FIPS==8119|FIPS==8121|FIPS==8123|FIPS==8125
** Exogeneity Check for all variables in 1920 1925 1930 1935 :
keep if Year>=1890


*twoway (kdensity Distance_Grazing_Treated ) (kdensity Mean_Dist)

gen HG_TGA = HG_Dummy*TGA


save "Create_AgriculturalCensus\Output\AgriCensus_Analysis_ExtendedStates.dta", replace


********************



*** Full file:
use "Create_AgriculturalCensus\Output\AgriCensus_Analysis.dta", clear

keep if Year>=1910 
* We use 1910 because that's when AZ got statehood and changes to county boundaries are minimal.
save "Create_AgriculturalCensus\Output\AC_1910.dta", replace