********************************************************************************
* This creates the Files for Appendix H: General Equilibrium Effects in the AC *
* Urban rural Share
* Population Panel
********************************************************************************

clear all
set more off

set maxvar 30000

tempfile temp intermediate temp2 t30 t25 t20 t10 t00 t90 test


use "Input\AC_1910.dta", clear
replace RE = . if Partial_Erosion==1
keep if RE!=.
rename Grazing_Area_Share GS
keep FIPS Year HG_Dummy STATE GS

keep if Year==1910

expand 10, gen(t)
sort FIPS Year t
bysort FIPS: replace t = sum(t)
replace t = t*10
replace Year = Year+t
drop t
replace Year = 1935 if Year==2000
duplicates report FIPS Year

save `temp', replace

********************************************************************************
*	1910
********************************************************************************

use "Create_AgriculturalCensus\Input\ICPSR_02896\DS0022\02896-0022-Data.dta", clear

gen Year = 1910

rename fips FIPS

rename urb910 urban 
rename rur1910 rural 

local list totpop urban rural 

keep Year FIPS `list'


format FIPS %5.0f
keep if FIPS!=.
duplicates drop FIPS, force

gen FIPS10 = FIPS

save `test', replace 


use "Create_AgriculturalCensus\Input\T1035.dta", clear
qui tab FIPS10
di `r(r)'

qui tab FIPS35
di `r(r)'

keep if FIPS35!=0&FIPS10!=0

gen Share = F_AREA/AREA10
sort FIPS10

merge m:1 FIPS10 using `test'

foreach var of varlist `list' {

replace `var' = `var'*Share
}

collapse (sum) `list' , by(FIPS35 Year)

rename FIPS35 FIPS

qui tab FIPS
di `r(r)'


merge 1:1 FIPS Year using `temp'
drop if _merge==1
rename _merge merge_1910

save `temp', replace

********************************************************************************
*	1920
********************************************************************************

use "Create_AgriculturalCensus\Input/ICPSR_02896/DS0024/02896-0024-Data.dta", clear

gen Year = 1920

rename fips FIPS

rename urb920 urban 
rename rur920 rural 

local list totpop urban rural 

format FIPS %5.0f
keep if FIPS!=.
duplicates drop FIPS, force

gen FIPS20 = FIPS

save `test', replace 


use "Create_AgriculturalCensus\Input\T2035.dta", clear
qui tab FIPS20
di `r(r)'

qui tab FIPS35
di `r(r)'

keep if FIPS20!=0&FIPS35!=0

gen Share = F_AREA/AREA20
sort FIPS20

merge m:1 FIPS20 using `test'

foreach var of varlist  `list'{
replace `var' = `var'*Share
}

collapse (sum) `list' , by(FIPS35 Year)

rename FIPS35 FIPS

merge 1:1 FIPS Year using `temp'
drop if _merge==1
rename _merge merge_1920

save `temp', replace



********************************************************************************
*	1930
********************************************************************************
use "Create_AgriculturalCensus\Input/ICPSR_02896/DS0026/02896-0026-Data.dta", clear

gen Year = 1930

rename fips FIPS

rename urb930 urban 
rename rural30 rural 
rename rurfarm ruralfarm
rename rurnfarm ruralnonfarm

local list totpop urban rural ruralfarm ruralnonfarm

format FIPS %5.0f
keep if FIPS!=.
duplicates drop FIPS, force

gen FIPS30 = FIPS

save `test', replace 


use "Create_AgriculturalCensus\Input\T3035.dta", clear
qui tab FIPS30
di `r(r)'

qui tab FIPS35
di `r(r)'

keep if FIPS30!=0&FIPS35!=0

gen Share = F_AREA/AREA30
sort FIPS30

merge m:1 FIPS30 using `test'

foreach var of varlist `list' {
replace `var' = `var'*Share
}

collapse (sum) `list'  , by(FIPS35 Year)

rename FIPS35 FIPS

merge 1:1 FIPS Year using `temp'
drop if _merge==1
rename _merge merge_1930

save `temp', replace


********************************************************************************
*	1935
********************************************************************************

use "Create_AgriculturalCensus\Input\ICPSR_35206\DS0015\35206-0015-Data.dta", clear

gen Year = 1935
gen totpop = VAR1
gen rural = VAR239


local list totpop rural 

format FIPS %5.0f
keep if FIPS!=.

#delimit ;
collapse (mean) `list' , by(FIPS Year);
	
#delimit cr
 
merge 1:1 FIPS Year using `temp'

drop if _merge==1
rename _merge merge_1935


save `temp', replace


********************************************************************************
*	1940
********************************************************************************

use "Create_AgriculturalCensus\Input\ICPSR_02896\DS0070\02896-0070-Data.dta", clear

gen Year = 1940

rename fips FIPS

rename totpop40 totpop
rename var10 urban 
gen rural = var11+var12
rename var12 ruralfarm


local list totpop urban rural ruralfarm

format FIPS %5.0f
keep if FIPS!=.

#delimit ;
collapse (mean) `list' , by(FIPS Year);
	
#delimit cr
 
merge 1:1 FIPS Year using `temp'

drop if _merge==1
rename _merge merge_1940


save `temp', replace



********************************************************************************
*	1950
********************************************************************************

use "Create_AgriculturalCensus\Input\ICPSR_02896\DS0072\02896-0072-Data.dta", clear

gen Year = 1950

rename fips FIPS

rename var2 totpop
rename var7 urban 
gen rural = var8+var9
rename var8 ruralnonfarm 
rename var9 ruralfarm


local list totpop urban rural ruralfarm ruralnonfarm

format FIPS %5.0f
keep if FIPS!=.

#delimit ;
collapse (mean) `list' , by(FIPS Year);
	
#delimit cr
 
merge 1:1 FIPS Year using `temp'

drop if _merge==1
rename _merge merge_1950


save `temp', replace


********************************************************************************
*	1960
********************************************************************************
local ds = "74"
use "Create_AgriculturalCensus\Input\ICPSR_02896\DS0074\02896-0074-Data.dta", clear

gen Year = 1960

rename fips FIPS

rename var3 totpop
rename var6 urban_share 
rename var7 ruralfarm_share


local list totpop urban_share ruralfarm_share

format FIPS %5.0f
keep if FIPS!=.

#delimit ;
collapse (mean) `list' , by(FIPS Year);
	
#delimit cr
 
merge 1:1 FIPS Year using `temp'

drop if _merge==1
rename _merge merge_1960


save `temp', replace



********************************************************************************
*	1970
********************************************************************************
local ds = "76"
use "Create_AgriculturalCensus\Input\ICPSR_02896\DS0076\02896-0076-Data.dta", clear

gen Year = 1970

rename fips FIPS

rename var3 totpop
rename var8 urban_share
rename var168 ruralnonfarm


local list totpop urban_share ruralnonfarm

format FIPS %5.0f
keep if FIPS!=.

#delimit ;
collapse (mean) `list' , by(FIPS Year);
	
#delimit cr
 
merge 1:1 FIPS Year using `temp'

drop if _merge==1
rename _merge merge_1970


save `temp', replace


********************************************************************************
*	1970
********************************************************************************
local ds = "77"
use "Create_AgriculturalCensus\Input\ICPSR_02896\DS0077\02896-0077-Data.dta", clear

gen Year = 1970

rename fips FIPS

rename var273 ruralfarm


local list ruralfarm

format FIPS %5.0f
keep if FIPS!=.

#delimit ;
collapse (mean) `list' , by(FIPS Year);
	
#delimit cr
 
merge 1:1 FIPS Year using `temp'

drop if _merge==1
drop _merge


save `temp', replace
	

********************************************************************************
*	1980

local ds = "78"
use "Create_AgriculturalCensus\Input\ICPSR_02896\DS0078\02896-0078-Data.dta", clear

gen Year = 1980

rename fips FIPS

rename var3 totpop
rename var6 urban
rename var205 ruralfarm


local list totpop urban ruralfarm

format FIPS %5.0f
keep if FIPS!=.

#delimit ;
collapse (mean) `list' , by(FIPS Year);
	
#delimit cr
 
merge 1:1 FIPS Year using `temp'

drop if _merge==1
rename _merge merge_1980


save `temp', replace



keep if HG_Dummy!=.


********************************************************************************
*** cleanup: 
********************************************************************************
sort FIPS Year
drop merge*

*** generate urbanity share

gen Urban_Share = urban/totpop 
replace Urban_Share = urban_share/100 if Urban_Share==.

gen Rural_Share = rural/totpop

gen RuralFarm_Share = ruralfarm_share/100
replace RuralFarm_Share = ruralfarm/rural if RuralFarm_Share==.
replace RuralFarm_Share = ruralfarm/(ruralfarm+ruralnonfarm) if RuralFarm_Share==.



replace urban = urban_share*totpop/100 if urban==.
gen lnUrban = log(urban+1)

replace rural = totpop-urban if rural==.
gen lnRural = log(rural+1)

gen lnPop = log(totpop+1)

keep FIPS Year Urban_Share RuralFarm_Share HG_Dummy STATE  lnRural lnUrban lnPop GS
keep if Year!=1990

gen TGA = (Year>1935)
gen HG_TGA=TGA*HG_Dummy
gen GS_TGA = TGA*GS

*** Instrument 
merge m:1 FIPS using "Input\AC_RainInstrument"
gen STD_TGA= STD_1934*TGA
drop _merge

save "Create_AgriculturalCensus/Output/AC_UrbanRural.dta", replace


********************************************************************************
* Create Population Panel
********************************************************************************

import delimited "Create_AgriculturalCensus\Input\nhgis0004_ts_nominal_county.csv", clear

tempfile test raw base append

rename year Year
rename a00aa Pop

gen FIPS = statefp*1000+countyfp

preserve
	keep if Year>=1940 
	save `base', replace
restore

save `raw', replace

**** 1910:
use `raw', clear
keep if Year==1910
keep FIPS Year Pop
format FIPS %5.0f
keep if FIPS!=.
duplicates drop FIPS, force
gen FIPS10 = FIPS

save `test', replace

use "Create_AgriculturalCensus\Input\T1035.dta", clear
qui tab FIPS10
di `r(r)'

qui tab FIPS35
di `r(r)'

keep if FIPS35!=0&FIPS10!=0

gen Share = F_AREA/AREA10
sort FIPS10

merge m:1 FIPS10 using `test'


foreach var of varlist Pop {

replace `var' = `var'*Share
}

collapse (sum) Pop , by(FIPS35 Year)

rename FIPS35 FIPS

qui tab FIPS
di `r(r)'

append using `base'
save `base', replace

**** 1920:
use `raw', clear
keep if Year==1920
keep FIPS Year Pop
format FIPS %5.0f
keep if FIPS!=.
duplicates drop FIPS, force
gen FIPS20 = FIPS

save `test', replace

use "Create_AgriculturalCensus\Input\T2035.dta", clear
qui tab FIPS20
di `r(r)'

qui tab FIPS35
di `r(r)'

keep if FIPS35!=0&FIPS20!=0

gen Share = F_AREA/AREA20
sort FIPS20

merge m:1 FIPS20 using `test'


foreach var of varlist Pop {

replace `var' = `var'*Share
}

collapse (sum) Pop , by(FIPS35 Year)

rename FIPS35 FIPS

qui tab FIPS
di `r(r)'

append using `base'
save `base', replace


**** 1930:
use `raw', clear
keep if Year==1930
keep FIPS Year Pop
format FIPS %5.0f
keep if FIPS!=.
duplicates drop FIPS, force
gen FIPS30 = FIPS

save `test', replace

use "Create_AgriculturalCensus\Input\T3035.dta", clear
qui tab FIPS30
di `r(r)'

qui tab FIPS35
di `r(r)'

keep if FIPS35!=0&FIPS30!=0

gen Share = F_AREA/AREA30
sort FIPS30

merge m:1 FIPS30 using `test'


foreach var of varlist Pop {

replace `var' = `var'*Share
}

collapse (sum) Pop , by(FIPS35 Year)

rename FIPS35 FIPS

qui tab FIPS
di `r(r)'

append using `base'
save `base', replace

keep FIPS Pop Year

expand 10

sort FIPS Year
gen n = 1
bysort FIPS Year: gen sn = sum(n)
replace Year = Year+sn-1
drop if Year==.
drop if FIPS==.
merge 1:1 FIPS Year using Input/AC_1910.dta, keepusing(FIPS)
keep if _merge==3
drop _merge

save "Create_AgriculturalCensus/Output/AC_Pop.dta", replace